@@ -23,6 +23,7 @@ import tempfile
 
 import tensorflow as tf
 from tensorflow_examples.lite.model_maker.core.task import model_util
+import tensorflow_hub as hub
 
 
 class BaseSpec(abc.ABC):
@@ -37,28 +38,22 @@ class BaseSpec(abc.ABC):
     tf.compat.v1.logging.info('Checkpoints are stored in %s', self.model_dir)
     self.strategy = strategy or tf.distribute.get_strategy()
 
-    self.expected_waveform_len = 44032
-    self.target_sample_rate = 44100
-    self.snippet_duration_sec = 1.
-
-  @abc.abstractmethod
-  def create_model(self, num_classes):
+  @abc.abstractproperty
+  def target_sample_rate(self):
     pass
 
   @abc.abstractmethod
-  def run_classifier(self, model, train_input_fn, validation_input_fn, epochs,
-                     steps_per_epoch, validation_steps):
+  def create_model(self, num_classes, train_whole_model=False):
     pass
 
-  # Default dummy augmentation that will be applied to train samples.
-  @tf.function
-  def data_augmentation(self, x, label):
-    return x, label
+  @abc.abstractmethod
+  def run_classifier(self, model, epochs, train_ds, validation_ds, **kwargs):
+    pass
 
-  # Default dummy preprocessing that will be applied to all data samples.
-  @tf.function
-  def preprocess(self, x, label):
-    return x, label
+  def preprocess_ds(self, ds, is_training=False):
+    """Returns a preprocessed dataset."""
+    _ = is_training
+    return ds
 
 
 def _remove_suffix_if_possible(text, suffix):
@@ -104,19 +99,55 @@ def _load_tfjs_speech_command_model():
 
 
 class BrowserFFTSpec(BaseSpec):
-  """Audio classification model spec using Browswer FFT as preprocessing."""
+  """Audio classification model spec using Browser FFT as preprocessing."""
 
   def __init__(self, model_dir=None, strategy=None):
     super(BrowserFFTSpec, self).__init__(model_dir, strategy)
     self._preprocess_model = _load_browser_fft_preprocess_model()
     self._tfjs_sc_model = _load_tfjs_speech_command_model()
+
     self.expected_waveform_len = self._preprocess_model.input_shape[-1]
 
-  @tf.function
-  def preprocess(self, x, label):
-    return tf.squeeze(self._preprocess_model(x), axis=0), label
+  @property
+  def target_sample_rate(self):
+    return 44100
 
-  def create_model(self, num_classes):
+  @tf.function
+  def _ensure_length(self, wav, unused_label):
+    return len(wav) >= self.expected_waveform_len
+
+  @tf.function
+  def _split(self, wav, label):
+    """Split the long audio samples into multiple trunks."""
+    # wav shape: (audio_samples, )
+    chunks = tf.math.floordiv(len(wav), self.expected_waveform_len)
+    unused = tf.math.floormod(len(wav), self.expected_waveform_len)
+    # Drop unused data
+    wav = wav[:len(wav) - unused]
+    # Split the audio sample into multiple chunks
+    wav = tf.reshape(wav, (chunks, 1, self.expected_waveform_len))
+
+    return wav, tf.repeat(tf.expand_dims(label, 0), len(wav))
+
+  @tf.function
+  def _preprocess(self, x, label):
+    # x has shape (1, expected_waveform_len)
+    spectrum = self._preprocess_model(x)
+    # y has shape (1, embedding_len)
+    spectrum = tf.squeeze(spectrum, axis=0)
+    # y has shape (embedding_len,)
+    return spectrum, label
+
+  def preprocess_ds(self, ds, is_training=False):
+    del is_training
+
+    autotune = tf.data.AUTOTUNE
+    ds = ds.filter(self._ensure_length)
+    ds = ds.map(self._split, num_parallel_calls=autotune).unbatch()
+    ds = ds.map(self._preprocess, num_parallel_calls=autotune)
+    return ds
+
+  def create_model(self, num_classes, train_whole_model=False):
     if num_classes <= 1:
       raise ValueError(
           'AudioClassifier expects `num_classes` to be greater than 1')
@@ -124,26 +155,21 @@ class BrowserFFTSpec(BaseSpec):
     for layer in self._tfjs_sc_model.layers[:-1]:
       model.add(layer)
     model.add(tf.keras.layers.Dense(units=num_classes, activation='softmax'))
-    # Freeze all but the last layer of the model. The last layer will be
-    # fine-tuned during transfer learning.
-    for layer in model.layers[:-1]:
-      layer.trainable = False
+    if not train_whole_model:
+      # Freeze all but the last layer of the model. The last layer will be
+      # fine-tuned during transfer learning.
+      for layer in model.layers[:-1]:
+        layer.trainable = False
     return model
 
-  def run_classifier(self, model, epochs, train_ds, train_steps, validation_ds,
-                     validation_steps, **kwargs):
+  def run_classifier(self, model, epochs, train_ds, validation_ds, **kwargs):
     model.compile(
-        optimizer='sgd',
+        optimizer='adam',
         loss='sparse_categorical_crossentropy',
         metrics=['acc'])
 
     hist = model.fit(
-        train_ds,
-        steps_per_epoch=train_steps,
-        validation_data=validation_ds,
-        validation_steps=validation_steps,
-        epochs=epochs,
-        **kwargs)
+        train_ds, validation_data=validation_ds, epochs=epochs, **kwargs)
     return hist
 
   def export_tflite(self, model, tflite_filepath, quantization_config=None):
@@ -176,3 +202,51 @@ class BrowserFFTSpec(BaseSpec):
 
     # Sets batch size back to None to support retraining later.
     model_util.set_batch_size(model, batch_size=None)
+
+
+class YAMNetSpec(BaseSpec):
+  """Audio classification model spec using YAMNet embedding."""
+
+  def __init__(self,
+               model_dir: None = None,
+               strategy: None = None,
+               yamnet_model_handle='https://tfhub.dev/google/yamnet/1'):
+    super(YAMNetSpec, self).__init__(model_dir, strategy)
+    self._yamnet_model_handle = yamnet_model_handle
+    self._yamnet_model = hub.load(yamnet_model_handle)
+
+  @property
+  def target_sample_rate(self):
+    return 16000
+
+  def create_model(self, num_classes, train_whole_model=False):
+    model = tf.keras.Sequential([
+        tf.keras.layers.Input(shape=(1024), dtype=tf.float32, name='embedding'),
+        tf.keras.layers.Dense(512, activation='relu'),
+        tf.keras.layers.Dense(num_classes, activation='softmax')
+    ])
+    return model
+
+  def run_classifier(self, model, epochs, train_ds, validation_ds, **kwargs):
+    model.compile(
+        optimizer='sgd',
+        loss='sparse_categorical_crossentropy',
+        metrics=['acc'])
+
+    hist = model.fit(
+        train_ds, validation_data=validation_ds, epochs=epochs, **kwargs)
+    return hist
+
+  @tf.function
+  def _extract_embedding(self, wav, label):
+    _, embeddings, _ = self._yamnet_model(wav)  # (chunks, 1024)
+    chunks = tf.shape(embeddings)[0]
+    labels = tf.repeat(tf.expand_dims(label, 0), chunks)  # (chunks,)
+    return embeddings, labels
+
+  def preprocess_ds(self, ds, is_training=False):
+    _ = is_training
+
+    autotune = tf.data.AUTOTUNE
+    ds = ds.map(self._extract_embedding, num_parallel_calls=autotune).unbatch()
+    return ds
